@@ -1,11 +1,11 @@
 //! The example in `winit`'s readme, adapted to use `winit-main`.
 
+use winit_main::reexports::{
+    event::{Event, WindowEvent},
+    window::WindowAttributes,
+};
 #[cfg(feature = "proc")]
 use winit_main::{
-    reexports::{
-        event::{Event, WindowEvent},
-        window::WindowAttributes,
-    },
     EventLoopHandle,
     EventReceiver,
 };
@@ -32,4 +32,22 @@ fn main(event_loop: EventLoopHandle, events: EventReceiver) {
 }
 
 #[cfg(not(feature = "proc"))]
-fn main() {}
\ No newline at end of file
+fn main() {
+    winit_main::run(|event_loop, events| {
+        let window = event_loop
+            .create_window(WindowAttributes::default())
+            .unwrap();
+
+        for event in events.iter() {
+            if matches!(
+                event,
+                Event::WindowEvent {
+                    event: WindowEvent::CloseRequested,
+                    window_id,
+                } if window_id == window.id()
+            ) {
+                break;
+            }
+        }
+    });
+}
